#
# spec file for package plexus-cli
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           plexus-cli
Version:        1.6
Release:        150200.3.4.3
Summary:        Command Line Interface facilitator for Plexus
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/codehaus-plexus/plexus-cli
Source0:        %{name}-%{version}.tar.xz
Source1:        LICENSE-2.0.txt
Source100:      %{name}-build.xml
Patch0:         0001-Do-not-use-commons-cli-deprecated-classes.patch
Patch1:         0002-No-unchecked-operations.patch
BuildRequires:  ant
BuildRequires:  apache-commons-cli
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-containers-container-default
BuildRequires:  plexus-utils
BuildRequires:  xz
Requires:       mvn(commons-cli:commons-cli)
Requires:       mvn(org.codehaus.plexus:plexus-container-default)
Requires:       mvn(org.codehaus.plexus:plexus-utils)
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
BuildRequires:  guava
%endif

%description
Plexus contains end-to-end developer tools for writing applications.
At the core is the container, which can be embedded or for an
application server. There are many reusable components for hibernate,
form processing, jndi, i18n, velocity, etc. Plexus also includes an
application server which is like a J2EE application server.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
cp -p %{SOURCE1} .
cp -p %{SOURCE100} build.xml

%pom_remove_parent

mkdir -p lib
build-jar-repository -s lib commons-cli plexus/utils plexus/classworlds plexus-containers/plexus-container-default
%if %{with tests}
build-jar-repository -s lib guava/guava
%endif

%build
ant \
%if %{without tests}
  -Dtest.skip=true \
%endif
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/plexus
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/plexus/cli.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/plexus
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/plexus/cli.pom
%add_maven_depmap plexus/cli.pom plexus/cli.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE-2.0.txt

%files javadoc
%license LICENSE-2.0.txt
%{_javadocdir}/%{name}

%changelog
* Thu May 19 2022 fstrba@suse.com
- Added patches:
  * 0001-Do-not-use-commons-cli-deprecated-classes.patch
    + the GnuParser and OptionBuilder classes are deprecated
    in commons-cli since version 1.3
    + port to the recommended DefaultParser and Option.builder(...)
  * 0002-No-unchecked-operations.patch
    + replace raw java.util.List with typed java.util.List<E>
    interface
* Sun Mar 20 2022 fstrba@suse.com
- Build with java source and target levels 8
* Tue Jan 18 2022 fstrba@suse.com
- Fetch sources using source service
* Tue May 11 2021 fstrba@suse.com
- Do not compile/run tests against the legacy guava20 package
* Sun Mar  3 2019 jengelh@inai.de
- Describe package, not project.
* Sat Mar  2 2019 fstrba@suse.com
- Initial package of plexus-cli 1.6
- Generate and customize the ant build file
